==> arquillian-parent-1.1.13.Final-source-release.zip: arquillian-parent-1.1.13.Final/protocols/jmx/src/test/java/org/jboss/arquillian/protocol/jmx/test/JMXTestTestRunner.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.jmx.test;

import org.jboss.arquillian.container.test.spi.command.Command;

/**
 * ARQ-469
 * Override send on original JMXTestRunner so we can simulate multi threaded behavior when running in container. 
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class JMXTestTestRunner extends org.jboss.arquillian.protocol.jmx.JMXTestRunner
{
   public JMXTestTestRunner(TestClassLoader classLoader)
   {
      super(classLoader);
   }

   @Override
   public void send(final Command<?> command)
   {
      final String currentCall = getCurrentCall();
      new Thread(new Runnable() {
         @Override
         public void run()
         {
            JMXTestTestRunner.this.setCurrentCall(currentCall);
            JMXTestTestRunner.super.send(command);
         }
      }).start();
   }
}

==> arquillian-parent-1.9.4.Final-source-release.zip: arquillian-parent-1.9.4.Final/protocols/jmx/src/test/java/org/jboss/arquillian/protocol/jmx/test/JMXTestTestRunner.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.jmx.test;

import org.jboss.arquillian.container.test.spi.command.Command;

/**
 * ARQ-469
 * Override send on original JMXTestRunner so we can simulate multi threaded behavior when running in container.
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 */
public class JMXTestTestRunner extends org.jboss.arquillian.protocol.jmx.JMXTestRunner {
    public JMXTestTestRunner(TestClassLoader classLoader) {
        super(classLoader);
    }

    @Override
    public void send(final Command<?> command) {
        final String currentCall = getCurrentCall();
        new Thread(new Runnable() {
            @Override
            public void run() {
                JMXTestTestRunner.this.setCurrentCall(currentCall);
                JMXTestTestRunner.super.send(command);
            }
        }).start();
    }
}
